@@ -1,5 +1,4 @@
-tts_google <- function(content="hello world",
-                              destfile=paste(getwd(),"r.mp3",sep="/")){
+tts_google <- function(content, destfile=paste(getwd(),"r.mp3",sep="/")){
   content_sparse <- strsplit(content,split = " ")[[1]]
 
   query_content <- content_sparse[1]
@@ -14,6 +13,6 @@ tts_google <- function(content="hello world",
   binary_file <- getURLContent(query)
   binary_file <- as.vector(binary_file)
   writeBin(binary_file, destfile)
-  cat("The voice file is generated in:",destfile,"\n")
+  cat("The voice file is generated in:",destfile,"\n\n")
 
 }
